package com.jfinal.club._admin.data.home.store;

import com.jfinal.aop.Inject;
import com.jfinal.club._admin.common.AdminCommonService;
import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.Area;
import com.jfinal.club.common.model.Store;
import com.jfinal.club.util.CommonUtil;
import com.jfinal.club.util.Cons;
import com.jfinal.club.util.MapUtils;
import com.jfinal.kit.Ret;
import com.jfinal.plugin.activerecord.Page;
import com.jfinal.upload.UploadFile;

import java.util.Date;
import java.util.List;

/**
 * @descriptions: 附近门店
 * @author: lc
 * @date: 2020-07-08 12:59:35
 * @Version: 1.0
 **/
public class AdminStoreController extends BaseController {

    @Inject
    AdminCommonService adminCommonService;
    public void index(){
        Page< Store > page = Store.dao.paginate(getInt("p", 1), getInt("s", Cons.FRONT_PAGESIZE), "select *", " from store order by sort desc,create_time desc");

        //把省市区 code转成name
        if(page.getList().size() > 0){
            page.getList().forEach(a ->{
                a.setProvince(adminCommonService.getOneByCode(a.getProvince( )).getAddrName());
                a.setCity(adminCommonService.getOneByCode(a.getCity( )).getAddrName());
                a.setDistrict(adminCommonService.getOneByCode(a.getDistrict( )).getAddrName());
            });
        }

        set("page",page);
        render("index.html");
    }


    public void add(){
        set("province",adminCommonService.listProvince());
        render("add_edit.html");
    }

    public void save(){
        UploadFile filepath = getFile("filepath",Cons.HOME_STORE);
        Store model = getModel(Store.class);
        if(filepath != null){
            model.setImg(CommonUtil.getFilePath(filepath,Cons.HOME_STORE));
        }
        //根据code 找到省市县name
        Area province = adminCommonService.getOneByCode(model.getProvince( ));
        Area city = adminCommonService.getOneByCode(model.getCity( ));
        Area district = adminCommonService.getOneByCode(model.getDistrict( ));
        // --

        //获取设置 经纬度
        String doorNumber = model.getDoorNumber( ) == null ? "" : model.getDoorNumber( );
        String address = model.getAddress() == null ? "": model.getAddress();
        String lastAddress = province.getAddrName() + city.getAddrName() + district.getAddrName() + address;
        String jsonStr = MapUtils.sendAddress(lastAddress);
        String longitudeAndLatitude = MapUtils.getLongitudeAndLatitude(jsonStr);
        String[] split = longitudeAndLatitude.split(",");
        model.setLongitude(split[0]);
        model.setLatitude(split[1]);
        //--
        model.setLastAddress(lastAddress + doorNumber);
        model.setFontAddress(district.getAddrName() + address+doorNumber);
        model.set("create_time",new Date()).save();
        renderJson(Ret.ok( ));
    }

    public void edit(){
        Store store = Store.dao.findById(getInt("id"));
        set("store",store);
        set("province",adminCommonService.listProvince());
        set("city",adminCommonService.listCityByProvinceCode(store.getProvince()));
        set("district",adminCommonService.listDistriceByCityCode(store.getCity()));
        render("add_edit.html");
    }

    public void update(){

        UploadFile filepath = getFile("filepath",Cons.HOME_STORE);
        Store model = getModel(Store.class);
        if(filepath != null){
            CommonUtil.deleteFile(Store.dao.findById(model.getId()).getImg());
            model.setImg(CommonUtil.getFilePath(filepath,Cons.HOME_STORE));
        }

        //根据code 找到省市县name
        Area province = adminCommonService.getOneByCode(model.getProvince( ));
        Area city = adminCommonService.getOneByCode(model.getCity( ));
        Area district = adminCommonService.getOneByCode(model.getDistrict( ));
        // --
        //获取设置 经纬度
        String doorNumber = model.getDoorNumber( ) == null ? "" : model.getDoorNumber( );
        String address = model.getAddress() == null ? "": model.getAddress();
        String lastAddress = province.getAddrName() + city.getAddrName() + district.getAddrName() + address;
        String jsonStr = MapUtils.sendAddress(lastAddress);
        String longitudeAndLatitude = MapUtils.getLongitudeAndLatitude(jsonStr);
        String[] split = longitudeAndLatitude.split(",");
        model.setLongitude(split[0]);
        model.setLatitude(split[1]);
        //--
        model.setLastAddress(lastAddress + doorNumber);
        model.setFontAddress(district.getAddrName() + address+doorNumber);
        model.update();
        renderJson(Ret.ok());
    }

    public void delete(){
        Integer id = getInt("id");
        CommonUtil.deleteFile(Store.dao.findById(id).getImg());
        Store.dao.deleteById(id);
        renderJson(Ret.ok());
    }


    public void listCityByProvince(){
        List< Area > areas = adminCommonService.listCityByProvinceCode(get("code"));
        renderJson(Ret.ok("data",areas));
    }

    public void listDistrictByCity(){
        List< Area > areas = adminCommonService.listDistriceByCityCode(get("code"));
        renderJson(Ret.ok("data",areas));
    }


    /**
     * 设置上下架
     */
    public void shelf_t(){
        Store store = Store.dao.findById(getInt("id"));
        store.setShelf(0);
        store.update();
        renderNull();
    }

    public void shelf_f(){
        Store store = Store.dao.findById(getInt("id"));
        store.setShelf(1);
        store.update();
        renderNull();
    }
}
