package com.jfinal.club._admin.data.product.pcolor;

import com.jfinal.aop.Inject;
import com.jfinal.club._admin.data.product.AdminProductService;
import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.PColor;
import com.jfinal.club.common.model.PMaterial;
import com.jfinal.club.common.model.Product;
import com.jfinal.club.util.CommonUtil;
import com.jfinal.club.util.Cons;
import com.jfinal.kit.Ret;
import com.jfinal.plugin.activerecord.Page;
import com.jfinal.upload.UploadFile;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @descriptions: 产品类型
 * @author: lc
 * @date: 2020-07-10 15:49:26
 * @Version: 1.0
 **/
public class AdminPColorController extends BaseController {

    @Inject
    AdminProductService adminProductService;

    public void index( ) {
        Integer type = getInt("type", -1);
        String searchName = get("searchName", "");
        set("searchName",searchName);
        set("type",type);
        ArrayList< Object > param = new ArrayList<>( );
        String sql = "  from p_color a INNER JOIN p_material b ON a.material_id = b.id where 1=1 ";

        if(type > -1){
            sql += " and material_id = ? ";
            param.add(type);
        }

        if(StringUtils.isNotBlank(searchName)){
            searchName = "%"+searchName.trim()+"%";
            sql += " and (code like ? or color_cn like ? )";
            param.add(searchName);
            param.add(searchName);
        }

        sql += " order by material_id asc,sort desc,create_time desc  ";
        Page< PColor > page = PColor.dao.paginate(getInt("p", 1), getInt("s", Cons.ADMIN_PAGESIZE), "select b.name,a.* ", sql,param.toArray());
        set("material",PMaterial.dao.find("select * from p_material order by sort desc,create_time desc"));
        set("page", page);
        render("index.html");
    }

    public void add( ) {
        keepPara("searchName","type","p","s");
        set("material",PMaterial.dao.find("select * from p_material order by sort desc,create_time desc"));
        render("add_edit.html");
    }

    public void save( ) {
        UploadFile file = getFile("filepath",Cons.PRODUCT_COLOR);

        PColor model = getModel(PColor.class,"p_color");

        if(file != null){
            model.setColorImg(CommonUtil.getFilePath(file,Cons.PRODUCT_COLOR));
        }

        model.set("create_time", new Date( )).save( );
        renderJson(Ret.ok( ));
    }

    public void edit( ) {
        keepPara("searchName","type","p","s");
        Integer id = getInt("id");
        set("p_color", PColor.dao.findById(id));
        set("material",PMaterial.dao.find("select * from p_material order by sort desc,create_time desc"));
        render("add_edit.html");
    }

    public void update( ) {
        UploadFile file = getFile("filepath",Cons.PRODUCT_COLOR);
        PColor model = getModel(PColor.class, "p_color");
        if(file != null){
            CommonUtil.deleteFile(PColor.dao.findById(model.getId()).getColorImg());
            model.setColorImg(CommonUtil.getFilePath(file,Cons.PRODUCT_COLOR));
        }
        model.update( );
        renderJson(Ret.ok( ));
    }


    public void delete( ) {
        Integer id = getInt("id");
        List< Product > productList = adminProductService.listByPColor(id);
        if (productList != null && productList.size( ) > 0) {
            renderJson(Ret.fail("msg", "请删除该类型下的所有产品信息!"));
        } else {
            PColor.dao.deleteById(id);
            renderJson(Ret.ok("msg", "删除成功!"));
        }
    }

    /**
     * 失焦排序
     */
    public void blur_sort(){
        PColor appcase = PColor.dao.findById(getInt("id"));
        if(appcase != null){
            appcase.setSort(getInt("sort"));
            appcase.update();
        }
        renderJson(Ret.ok());
    }
}
