package com.jfinal.club._admin.data.product.product;

import com.jfinal.club.common.model.*;
import com.jfinal.club.util.CommonUtil;
import com.jfinal.club.util.Cons;
import com.jfinal.club.util.ExcelUtils;
import com.jfinal.club.vo.ExcelUploadResultVo;
import com.jfinal.kit.PathKit;
import com.jfinal.plugin.activerecord.Db;
import org.apache.commons.lang.time.DateUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.usermodel.WorkbookFactory;

import java.io.*;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @descriptions:
 * @author: lc
 * @date: 2020-08-27 18:00:21
 * @Version: 1.0
 **/
public class AdminExcelService {

    private int rowNull = 0;

    private final String baseUrl = "\\\\192.168.3.176\\data\\项目资料\\好博\\2020年8月26日客户邮寄产品图片-终版\\";
    private final String gcbaseUrl = "\\\\192.168.3.176\\data\\项目资料\\好博\\工差图\\";
    private final String brassFolder = "Messing_Brass"; //黄铜 M
    private final String steelFolder = "Edelstahl_Stainless-steel"; //不锈钢 E
    private final String aluminiumFolder = "Aluminium"; //铝合金 其他

    /**
     * excel导入 文件上传
     *
     * @param file
     * @return 返回一个上传结果  ExcelUploadResultVo
     */
    public ExcelUploadResultVo< Product > fileUpload(File file) {
        rowNull = 0;
        ExcelUploadResultVo vo = new ExcelUploadResultVo( );

        if (file == null) {
            vo.setMsgTip("请选择文件!");
            return vo;
        }

        String name = file.getName( );
        String suffix = name.substring(name.lastIndexOf(".") + 1);
        if (!(suffix.equals("xls") || suffix.equals("xlsx"))) {
            vo.setMsgTip("请上传excel文件!");
            return vo;
        }
        try {
            // 对读取Excel表格标题测试
            InputStream is = new FileInputStream(file);
            Workbook workbook = null;
            try {
                workbook = WorkbookFactory.create(is);
            } catch (Exception e) {
                file.delete( );
                vo.setMsgTip("上传模板有误! 请去上页下载导入模板! ");
                return vo;
            }
            Sheet sheet1 = workbook.getSheetAt(0);
            System.err.println("last rows length " + sheet1.getLastRowNum( ));
            //获取表头
            Row row = sheet1.getRow(0);
            if (row.getLastCellNum( ) != 29) {
                vo.setMsgTip("上传模板有误!下载导入模板! ");
                return vo;
            }

            if (sheet1.getLastRowNum( ) < 1) {
                vo.setMsgTip("该文件没有任何数据!");
                return vo;
            }

            int totalData = sheet1.getLastRowNum( );
            //返回失败的信息
            List< Product > failList = dealData(sheet1);
            vo.setMsgTip(" 总共" + totalData + "条数据! 导入成功" + ((totalData - failList.size( )) - rowNull) + "条," + "失败" + failList.size( ) + "条,空行数据" + rowNull + "条 ");
            vo.setFailList(failList);
            return vo;
        } catch (IOException e) {
            System.out.println("未找到指定路径的文件!");
            e.printStackTrace( );
        }

        vo.setMsgTip("*** Program upload exception! ****");
        return vo;
    }


    /**
     * 处理数据
     * /*            * 室内门把手
     * * 推拉门扣手
     * * 型材门把手
     * * HCS 整体系统锁
     * * 大拉手
     * * 阳台门提升
     * * 窗把手
     * * 阳台门内倒
     * * 合页
     * * 锁体
     * * 锁芯
     */
    public List< Product > dealData(Sheet sheet1) {


        //成功上传的数据信息
        ArrayList< Product > successList = new ArrayList<>( );
        //上传失败的信息 ,并告知错误的数据
        ArrayList< Product > failList = new ArrayList<>( );
        String failStr = "";
        List< PTitle > pTitles = PTitle.dao.find("select * from p_title");

        for (int i = 1; i <= sheet1.getLastRowNum( ); i++) {
            Row row1 = sheet1.getRow(i);
            Product p = new Product( );
            p.setVersionInfo("");
            p.setDoorType("");
            p.setIntoPieces("");
            p.setUnit("");
            p.setFixedDistance("");
            p.setCenterDistance("");
            p.setPedestal("");
            //p.setPackingUnit("");
            p.setPanelSize("");
            p.setDoorMargin("");
            p.setMeasure("");
            p.setVolumeKeys("");
            p.setCoverImg("");
            p.setAxialLength("");
            p.setDoorThickness("");
            p.setAxialSize("");
            p.setContent("");
            p.setImg("");
            p.setColorName("");
            p.setImgKeyhole("");
            //4series  5product 6productName 7productNam2e  8productLine   24Item-textGermanPIM 产品介绍取技术标准
            String series = ExcelUtils.getValue(row1.getCell(4));
            String product = ExcelUtils.getValue(row1.getCell(5));
            String productName = ExcelUtils.getValue(row1.getCell(6));
            String productName2 = ExcelUtils.getValue(row1.getCell(7)).replace(" ", "");
            String productLine = ExcelUtils.getValue(row1.getCell(8));
            String itemText = ExcelUtils.getValue(row1.getCell(24));

            int index = productName.lastIndexOf(" ");
            if (index > 0) {
                productName = productName.substring(0, index);
            }
            productName = productName.replaceAll(" ", "").trim( );
            int type = dataType(series, productName);
            p.setPType(type);//产品类型
            p.setPCode(product); //产品代码编码
            //查看是否存在该款式
            Integer pTitleId = 0;
            for (int j = 0; j < pTitles.size( ); j++) {
                PTitle pTitle = pTitles.get(j);
                if (pTitle.getName( ).equals(series.trim( ))) {
                    pTitleId = pTitle.getId( );
                    break;
                }
            }
            if (pTitleId == 0) {
                PTitle pTitle1 = new PTitle( );
                pTitle1.setName(series.trim( ));
                pTitle1.setSort(0);
                pTitle1.setCreateTime(new Date( ));
                pTitle1.save( );
                pTitles.add(pTitle1);
                pTitleId = pTitle1.getId( );
            }
            //判断材质 M铜，C不锈钢 ，其他铝合金
            int materialId = material(productName);


            String reg = "<strong>(.*?)</strong>";

            Pattern compile = Pattern.compile(reg);
            Matcher matcher = compile.matcher(itemText);
            String tempContent = "";
            while (matcher.find( )) {
                tempContent += matcher.group( );
            }
            p.setContent(tempContent);

            //产品专利技术
            if ("NORM".equalsIgnoreCase(productLine)) {
                p.setPPatent("1");
            }
            if ("PLUS".equalsIgnoreCase(productLine)) {
                p.setPPatent("2");
            }
            if ("VERT".equalsIgnoreCase(productLine)) {
                p.setPPatent("3");
            }
            p.setModel(productName);//型号
            p.setPMaterial(materialId); //材料
            p.setPTitle(pTitleId); // 名称
            //颜色名称

            String[] split1 = productName2.split("/");
            for (int j = 0; j < split1.length; j++) {
                String s = split1[j];
                if (s.startsWith("F")) {
                    PColor first = PColor.dao.findFirst("select * from p_color where code = ? ", s);
                    if(first != null){
                        p.setColorName(s+" "+first.getColorCn());
                        p.setPColor(first.getId());
                    }else{
                        failStr += s+",";
                    }
                    break;
                }
            }
            if (type == 1) {
                String[] split = productName2.split("/");
                int tempIndex = 0;
                for (int j = 0; j < split.length; j++) {
                    String s = split[j];
                    if ("9999".equals(s.trim( ))) {
                        tempIndex = j;
                        break;
                    }
                }

                // System.err.println(productName2+"门厚："+ split[tempIndex-1].trim() + "  轴长: "+split[tempIndex-3].trim());
                if (tempIndex != 0) {
                    p.setDoorThickness(split[tempIndex - 1].trim( ));
                    p.setAxialLength("8");
                }

                p.setImgKeyhole("/assets/img/icon_sk.png");
            } else if (type == 2) {
                //版本
                p.setVersionInfo("光面(不开孔)");
                if (productName2.contains("BLIND")) {
                    p.setDoorThickness("35");
                } else {
                    String[] split = productName2.split("/");
                    int tempIndex = 0;
                    for (int j = 0; j < split.length; j++) {
                        String s = split[j];
                        if ("9999".equals(s.trim( ))) {
                            tempIndex = j;
                            break;
                        }
                    }
                    if (tempIndex != 0) {
                        p.setDoorThickness(split[tempIndex - 1].trim( ));
                        p.setAxialLength("8");
                    }
                }

            } else if (type == 3) {

                String[] split = productName2.split("/");
                int tempIndex = 0;
                for (int j = 0; j < split.length; j++) {
                    String s = split[j];
                    if ("9999".equals(s.trim( ))) {
                        tempIndex = j;
                        break;
                    }
                }

                if (tempIndex != 0) {
                    if (productName2.contains("RFL8")) {
                        p.setDoorThickness(split[tempIndex - 2].trim( ));

                    } else if (productName2.contains("RFL-R")) {
                        p.setDoorThickness(split[tempIndex - 3].trim( ));
                    } else {
                        p.setDoorThickness(split[tempIndex - 1].trim( ));
                    }
                    p.setAxialLength("8");
                }
                p.setImgKeyhole("/assets/img/icon_sk.png");
            } else if (type == 4) {
                //HCS
                p.setDoorType("平口木门");//门类型
                p.setIntoPieces("不含"); //撞片
                p.setDoorThickness("35-43");//门厚

            } else if (type == 5) {
                p.setUnit("个"); //单位 个
                String[] split = productName2.split("/");
                for (int j = 0; j < split.length; j++) {
                    String s = split[j];
                    if (isInt(s)) {
                        if (Integer.valueOf(s) >= 210 && Integer.valueOf(s) <= 250) {
                            p.setFixedDistance(s); //固定距离
                        }
                    }
                }

            } else if (type == 6) {
                p.setDoorThickness("75-80");//门厚
                p.setAxialLength("10");//轴长 方轴尺寸
                if (productName2.contains("PZ-69")) {
                    p.setCenterDistance("69"); //中心距
                    p.setImgKeyhole("/upload/锁孔");
                } else {
                    p.setCenterDistance("无");//中心距
                    p.setImgKeyhole("");
                }
                p.setImgKeyhole("/assets/img/icon_sk.png");
            } else if (type == 7) {
                String[] split = productName2.split("/");
                int tempIndex = 0;
                for (int j = 0; j < split.length; j++) {
                    String s = split[j];
                    if ("9999".equals(s.trim( ))) {
                        tempIndex = j;
                        break;
                    }
                }

                if (tempIndex != 0) {
                    if (split[tempIndex - 2].trim( ).equals("90")) {
                        p.setAxialLength("0"); //轴长
                    } else if (split[tempIndex - 2].trim( ).equals("PZ")) {
                        p.setAxialLength("0"); //轴长
                    } else if (split[tempIndex - 2].trim( ).equals("070UNGEK")) {
                        p.setAxialLength("0"); //轴长
                    } else {
                        p.setAxialLength(split[tempIndex - 2].trim( )); //轴长
                    }
                    p.setAxialSize("7"); //轴尺寸
                    //System.err.println("轴长"+p.getAxialLength() + " 轴尺寸 "+split[tempIndex - 3].trim( ));
                }

                p.setPedestal("半盖式"); //  半盖式/ 全盖式 两种
            } else if (type == 8) {
                // System.err.println(productName + " ===================" + productName2  );

                String[] split = productName2.split("/");
                int tempIndex = 0;
                for (int j = 0; j < split.length; j++) {
                    String s = split[j];
                    if ("9999".equals(s.trim( ))) {
                        tempIndex = j;
                        break;
                    }
                }

                if (tempIndex != 0) {
                    if (split[tempIndex - 2].trim( ).equals("90")) {
                        p.setAxialLength("0"); //轴长
                    } else if (split[tempIndex - 2].trim( ).equals("050UNGEK")) {
                        p.setAxialLength("0"); //轴长
                    } else {
                        p.setAxialLength(split[tempIndex - 2].trim( )); //轴长
                    }
                    p.setAxialSize("7"); //轴尺寸
                }
                p.setPedestal("半盖式"); //  半盖式/ 全盖式 两种
            } else if (type == 9) {
                //p.setPackingUnit("2片");
                if (productName.contains("AR8280")) {
                   // p.setPackingUnit("3片");// 包装量
                }


            } else if (type == 10) {
                if (productName.equals("AR-MAG-LOCK")) continue;
                String[] split = productName2.split("/");
                int tempIndex = 0;
                for (int j = 0; j < split.length; j++) {
                    String s = split[j];
                    if ("A".equals(s.trim( ))) {
                        tempIndex = j;
                        break;
                    }
                }

                if (tempIndex != 0) {
                    p.setPanelSize(split[tempIndex - 2].trim( )); //面板体积
                    String center = split[tempIndex - 3].trim( );
                    p.setCenterDistance(center.split("-")[1]); //中心距
                    String doorMargin = split[tempIndex - 4].trim( );
                    p.setDoorMargin(doorMargin.split("-")[0]); //门边距
                    // System.err.println("面板体积：" + split[tempIndex - 2].trim( ) +" 中心距： "+center.split("-")[1] + "门边距： "+ doorMargin.split("-")[0]);
                }
                p.setImgKeyhole("/assets/img/icon_sk.png");
            } else if (type == 11) {
                String[] split = productName2.split("/");
                p.setMeasure(split[0] + "/" + split[0]); //尺寸
                if (productName.equalsIgnoreCase("AR683")) {
                    p.setVolumeKeys("无");
                } else {
                    p.setVolumeKeys("3");
                }
            } else {
                //没有
            }

            p.setCreateTime(new Date( ));
            p.setModifiedTime(new Date( ));
            p.setSort(0);
            p.setIsRecommend(0);

            String imgPath = imgPath(productName, productName2);
            System.err.println("产品图 ===== "+imgPath );
            String path = CommonUtil.imgUpload(imgPath, "cover_img");
            p.setCoverImg(path);
            p.setImg(path);

            String img_sample_path = gcImgPath(productName);
            System.err.println("工差图 ===== "+img_sample_path );
            String img_sample = CommonUtil.imgUpload(img_sample_path, "img_sample");
            p.setImgSample(img_sample);

            successList.add(p);
        }
        System.err.println("失败的ffff"+failStr );
        int[] ints = Db.batchSave(successList, 1000);
        System.err.println("批量" + (ints.length) + "条数据,添加成功 ...... ");
        return failList;
    }

    private boolean isInt(String str) {
        try {
            Integer.valueOf(str);
            return true;
        } catch (NumberFormatException e) {
            return false;
        }
    }


    /**
     * 室内门把手
     * 推拉门扣手
     * 型材门把手
     * HCS 整体系统锁
     * 大拉手
     * 阳台门提升
     * 窗把手
     * 阳台门内倒
     * 合页
     * 锁体
     * 锁芯
     * 判断数据 类型
     *
     * @param series
     * @param productName
     * @return
     */
    public int dataType(String series, String productName) {

        //室内门把手
        if (sndoor(productName)) {
            return 1;
        }
        //推拉门扣手
        if (tldoor(productName)) {
            return 2;
        }
        //型材门把手
        if (xcdoor(productName)) {
            return 3;
        }
        // HCS 整体系统锁
        if (hcs(productName)) {
            return 4;
        }
        //大拉手
        if (dls(productName)) {
            return 5;
        }
        //阳台门提升
        if (yt(productName)) {
            return 6;
        }
        //窗把手
        if (cbs(productName)) {
            return 7;
        }
        //阳台门内倒
        if (ytn(productName)) {
            return 8;
        }
        //合页
        if (hy(series)) {
            return 9;
        }
        //锁体
        if (st(series)) {
            return 10;
        }
        //锁芯
        if (sx(series)) {
            return 11;
        }

        return 12;
    }

    /**
     * 1 青铜 2 不锈钢  3 铝合金
     *
     * @param productName
     * @return
     */
    public int material(String productName) {
        if (productName.contains("M")) {
            return 1;
        }
        boolean matches1 = Pattern.matches("^E.*$", productName);
        boolean matches2 = Pattern.matches("^HS-E.*$", productName);
        boolean matches3 = Pattern.matches("^PSK-E.*$", productName);
        if (matches1 || matches2 || matches3) {
            return 2;
        }
        return 3;
    }

    /**
     * 室内门把手（带有1开头）
     *
     * @param productName
     * @return
     */
    public boolean sndoor(String productName) {
        boolean matches = Pattern.matches("^[a-zA-Z]1.*$", productName);
        boolean matches1 = Pattern.matches("^1.*$", productName);
        if (matches || matches1) {
            // 双斜线的表示是  型材门把手 1737/843K/843KS 求有几个斜线
            int count = findCount(productName, "/");
            if (count == 2) {
                return false;
            } else {
                return true;
            }
        }
        return false;
    }

    /**
     * 推拉门扣手 （带有4开头）（476 或 5开头的是大拉手）
     *
     * @return
     */
    public boolean tldoor(String productName) {
        boolean matches = Pattern.matches("^[a-zA-Z]4.*$", productName);
        boolean matches1 = Pattern.matches("^4.*$", productName);
        if (matches || matches1) {
            // 476 或 5开头的是大拉手类型
            boolean matches2 = Pattern.matches("^[a-zA-Z]476.*$", productName);
            if (matches2) {
                return false;
            } else {
                return true;
            }
        }
        return false;
    }

    /**
     * 3 型材门把手
     *
     * @param
     */
    public boolean xcdoor(String productName) {
        boolean matches = Pattern.matches("^[a-zA-Z]1.*$", productName);
        boolean matches1 = Pattern.matches("^1.*$", productName);
        if (matches || matches1) {
            // 双斜线的表示是  型材门把手 1737/843K/843KS 求有几个斜线
            int count = findCount(productName, "/");
            if (count == 2) {
                return true;
            } else {
                return false;
            }
        }
        return false;
    }

    /**
     * 合页
     *
     * @param series
     * @return
     */
    public boolean hy(String series) {
        if ("hinges".equalsIgnoreCase(series)) {
            return true;
        }
        return false;
    }

    /**
     * 锁体
     *
     * @param series
     * @return
     */
    public boolean st(String series) {
        if ("locks".equalsIgnoreCase(series)) {
            return true;
        }
        return false;
    }

    /**
     * 锁芯
     *
     * @param series
     * @return
     */
    public boolean sx(String series) {
        if ("CYL".equalsIgnoreCase(series)) {
            return true;
        }
        return false;
    }

    /**
     * hcs 整体系统锁
     *
     * @param productName
     * @return
     */
    public boolean hcs(String productName) {
        if (productName.contains("HCS")) {
            return true;
        }
        return false;
    }

    /**
     * 大拉手 以(476或者5开头的)
     *
     * @param productName
     * @return
     */
    public boolean dls(String productName) {
        boolean matches = Pattern.matches("^[a-zA-Z]476.*$", productName);
        boolean matches1 = Pattern.matches("^[a-zA-Z]5.*$", productName);
        if (matches || matches1) {
            return true;
        }
        return false;
    }

    /**
     * 阳台门用提升/ 推拉门把手
     * HS 开头
     *
     * @param productName
     * @return
     */
    public boolean yt(String productName) {
        if (productName.startsWith("HS")) {
            return true;
        }
        return false;
    }

    /**
     * 窗把手
     *
     * @param productName
     * @return
     */
    public boolean cbs(String productName) {
        boolean matches = Pattern.matches("^0.*$", productName);
        boolean matches1 = Pattern.matches("^[a-zA-Z]0.*$", productName);
        if (matches || matches1) {
            return true;
        }
        return false;
    }

    /**
     * 阳台门 内倒/ 推拉门把手
     * psk 开头
     *
     * @param productName
     * @return
     */
    public boolean ytn(String productName) {
        if (productName.startsWith("PSK")) {
            return true;
        }
        return false;
    }


    public static void main(String[] args) throws UnsupportedEncodingException {
        //铝合金
        String baseUrl = "file://192.168.3.176/data/项目资料/好博/2020年8月26日客户邮寄产品图片-终版/Aluminium/1530";
        String t = "1530";
        String f = "F1";
        File file = new File("\\\\192.168.3.176\\data\\项目资料\\好博\\2020年8月26日客户邮寄产品图片-终版\\Aluminium\\1530");
        File[] files = file.listFiles( );
        for (int i = 0; i < files.length; i++) {
            if (files[i].toString( ).contains("1530-3346")) {
                if (files[i].toString( ).contains("F1")) {
                    System.err.println(files[i]);
                }
            }
        }
    }

    //BS EN 1935：2002  //BS EN 1634
    public static int findCount(String src, String des) {
        int index = 0;
        int count = 0;
        while ((index = src.indexOf(des, index)) != -1) {
            count++;
            index = index + des.length( );
        }
        /*System.out.println(des+"出现了 "+count+" 次");*/
        return count;
    }


    public String imgPath(String productName, String productName2) {
        String filePath = "";

        if("M515LG".equals(productName)){
            productName = "M515";
        }

        String fileName = "";
        String[] split1 = productName2.split("/");
        for (int i = 0; i < split1.length; i++) {
            String s = split1[i];
            if (s.startsWith("F")) {
                fileName = s;
                break;
            }
        }


        int materialId = material(productName);
        String tempFolder;
        if (materialId == 1) {
            tempFolder = brassFolder;
        } else if (materialId == 2) {
            tempFolder = steelFolder;
        } else {
            tempFolder = aluminiumFolder;
        }

        if(productName.startsWith("AR")){
            tempFolder = "Arrone";
        }

        productName = productName.replaceAll(" ", "");
        productName = productName.replaceAll("/", "-");
        String[] split = productName.split("-");
        if(productName.startsWith("PSK") || productName.startsWith("HS")){
            tempFolder = tempFolder + "\\" + split[0]+"-"+split[1];//临时目录
        }else{
            tempFolder = tempFolder + "\\" + split[0];//临时目录
        }
        String folderUrl = baseUrl + tempFolder;

        File file = new File(folderUrl);
        File[] files = file.listFiles( );
        if(files == null){
            System.err.println( );
        }
        if (files != null) {
            for (int i = 0; i < files.length; i++) {

                if (files[i].toString( ).contains(productName)) {
                    File file1 = files[i];
                    String name = file1.getName( ).replace("-","");
                    if (name.contains(fileName.replace("-",""))) {
                        filePath = files[i].toString( );
                        break;
                    }
                }
            }
        }


        //HCS 版
        if(productName.startsWith("HCS")){
            String s = hcsImg(productName, materialId, fileName);
            filePath = s;
        }


/*        if("".equals(filePath)){
            System.err.println("****"+productName );
        }*/
        return filePath;
    }

    public String hcsImg(String productName,int materialId,String fileName){
        if(productName.equals("HCSM1950S")){
            productName = "HCSM1950";
        }
        if(productName.equals("HCSM156S")){
            productName = "HCSM156";
        }
        if(productName.equals("HCSA138S")){
            productName = "HCSA138";
        }
        if(productName.equals("HCSA197S")){
            productName = "HCSA197";
        }
        if(productName.equals("HCSK138S")){
            productName = "HCSK138";
        }


        String filePath = "";
        String hcsUrl = "\\\\192.168.3.176\\data\\项目资料\\好博\\2020年8月26日客户邮寄产品图片-终版\\HCS\\";
        String hcs = productName.replace("HCS", "");
        hcs = "HCS-"+hcs;
        String tempFolder="";
        if(materialId == 1){
            tempFolder = "Messing\\";
        }else if(materialId == 2){
            tempFolder = "Kunststoff\\";
        }else {
            tempFolder = "Aluminium\\";
        }

        if(productName.equals("HCSK138")){
            tempFolder = "Kunststoff\\";
        }

        hcsUrl = hcsUrl + tempFolder + hcs;

        File file = new File(hcsUrl);
        File[] files = file.listFiles( );

        if (files != null) {
            for (int i = 0; i < files.length; i++) {

                if (files[i].toString( ).contains(hcs)) {
                    File file1 = files[i];
                    String name = file1.getName( ).replace("-","");
                    if (name.contains(fileName.replace("-",""))) {
                        filePath = files[i].toString( );
                        break;
                    }
                }
            }
        }

        return filePath;
    }



    public String gcImgPath(String productName) {
        String filePath = "";

        String fileName = productName.replace("/","");

        int materialId = material(productName);
        String tempFolder;
        if (materialId == 1) {
            tempFolder = brassFolder;
        } else if (materialId == 2) {
            tempFolder = steelFolder;
        } else {
            tempFolder = aluminiumFolder;
        }

        if(productName.startsWith("AR")){
            tempFolder = "Arrone";
        }

        productName = productName.replaceAll(" ", "");
        productName = productName.replaceAll("/", "-");
        String[] split = productName.split("-");
        tempFolder = tempFolder + "\\" + split[0];//临时目录
        String folderUrl = gcbaseUrl + tempFolder;

        File file = new File(folderUrl);
        File[] files = file.listFiles( );
        if(files == null){
            System.err.println( );
        }
        if (files != null) {
            for (int i = 0; i < files.length; i++) {
                String name = files[i].getName( ).replace("-","");
                if(name.contains(".jpg")){
                    if(name.contains(fileName)){
                        filePath = files[i].toString( );
                        break;
                    }
                }
            }
        }


        //HCS 版
        if(productName.startsWith("HCS")){
            String s = gcHcsImg(productName, materialId, fileName);
            filePath = s;
        }


/*        if("".equals(filePath)){
            System.err.println("****"+productName );
        }*/
        return filePath;
    }

    public String gcHcsImg(String productName,int materialId,String fileName){
        if(productName.equals("HCSM1950S")){
            productName = "HCSM1950";
        }
        if(productName.equals("HCSM156S")){
            productName = "HCSM156";
        }
        if(productName.equals("HCSA138S")){
            productName = "HCSA138";
        }
        if(productName.equals("HCSA197S")){
            productName = "HCSA197";
        }
        if(productName.equals("HCSK138S")){
            productName = "HCSK138";
        }


        String filePath = "";
        String hcsUrl = "\\\\192.168.3.176\\data\\项目资料\\好博\\工差图\\HCS\\";
        String hcs = productName.replace("HCS", "");
        hcs = "HCS-"+hcs;
        String tempFolder="";
        if(materialId == 1){
            tempFolder = "Messing\\";
        }else if(materialId == 2){
            tempFolder = "Kunststoff\\";
        }else {
            tempFolder = "Aluminium\\";
        }

        if(productName.equals("HCSK138")){
            tempFolder = "Kunststoff\\";
        }

        hcsUrl = hcsUrl + tempFolder + hcs;

        File file = new File(hcsUrl);
        File[] files = file.listFiles( );

        if (files != null) {
            for (int i = 0; i < files.length; i++) {
                String name = files[i].getName( );
                if(name.contains(".jpg")){
                    if(name.contains(fileName)){
                        filePath = files[i].toString( );
                        break;
                    }
                }
            }
        }

        return filePath;
    }


    public void createExcel( ) {

        //excel标题
        String[] title = {"语言","公司","姓名","联系地址","国家","人员规模","联系电话","邮箱","所属行业","兴趣意向","了解产品","创建时间"};
        //sheet名
        String sheetName = "展会登记人员信息表";

        List< RegistrationForm > list = RegistrationForm.dao.find(" select * from registration_form order by create_time desc ");
        if(list == null && list.size() <= 0){
            return;
        }

        String [][] content = new String[list.size()][13];

        for (int i = 0; i < list.size(); i++) {
            content[i] = new String[title.length];
            RegistrationForm obj = list.get(i);
            if(obj.getLanguage() == null){
                content[i][0] = "中文";
            }else{
                content[i][0] = obj.getLanguage()== 1 ?"中文":"英文";
            }

            if(StringUtils.isBlank(obj.getCompany())){
                content[i][1] = "";
            }else{
                content[i][1] = obj.getCompany();
            }
            if(StringUtils.isBlank( obj.getName())){
                content[i][2] = "";
            }else{
                content[i][2] = obj.getName();
            }

/*            String pcd = "";
            if(StringUtils.isBlank(obj.getProvince())){
                pcd = "";
            }else{
                pcd = obj.getProvince();
            }

            if(StringUtils.isBlank(obj.getCity())){
                pcd += "";
            }else{
                pcd += obj.getCity();
            }

            if(StringUtils.isBlank(obj.getDistrict())){
                pcd += "";
            }else{
                pcd += obj.getProvince();
            }
            content[i][3] = pcd;*/

            if(StringUtils.isBlank(obj.getAddress())){
                content[i][3] = "";
            }else{
                content[i][3] = obj.getAddress();
            }

            if(StringUtils.isBlank(obj.getCountry())){
                content[i][4] = "";
            }else{
                content[i][4] = obj.getCountry();
            }

            if(StringUtils.isBlank(obj.getStaffSize())){
                content[i][5] = "";
            }else{
                content[i][5] = obj.getStaffSize();
            }

            if(StringUtils.isBlank(obj.getPhone())){
                content[i][6] = "";
            }else{
                content[i][6] = obj.getPhone();
            }

            if(StringUtils.isBlank( obj.getEmail())){
                content[i][7] = "";
            }else{
                content[i][7] = obj.getEmail();
            }

            String industry = "";
            if(StringUtils.isBlank(obj.getIndustry())){
                industry += "";
            }else{
                industry += obj.getIndustry();
            }
            if(StringUtils.isBlank(obj.getIndustryOther())){
                industry += "";
            }else{
                industry += ","+obj.getIndustryOther();
            }
            content[i][8] =industry;

            String interest = "";
            if(StringUtils.isBlank(obj.getInterest())){
                interest = "";
            }else{
                interest = obj.getInterest();
            }

            if(StringUtils.isBlank(obj.getInterestOther())){
                interest += "";
            }else{
                interest += ","+obj.getInterestOther();
            }
            content[i][9] = interest;

            if(StringUtils.isBlank(obj.getKnowProduct())){
                content[i][10] = "";
            }else{
                content[i][10] = obj.getKnowProduct();
            }

            if(obj.getCreateTime() == null){
                content[i][11] = "";
            }else{
                content[i][11] =  DateFormatUtils.format(obj.getCreateTime(), "yyyy:MM:dd HH:mm:ss");
            }

        }

        //创建HSSFWorkbook
        HSSFWorkbook wb = ExcelUtils.getHSSFWorkbook(sheetName, title, content, null);

        //响应到客户端
        try {
            FileOutputStream out = new FileOutputStream(new File(PathKit.getWebRootPath(),"upload"+ Cons.EXPORT_SERVICE_NETWORK));
            wb.write(out);
            out.flush();
            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

    }
}
