package com.jfinal.club._admin.data.sys;

import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.Admins;
import com.jfinal.club.common.model.Navbar;
import com.jfinal.club.common.model.News;
import com.jfinal.club.util.CacheSessionUtil;
import com.jfinal.club.util.Cons;
import com.jfinal.club.vo.AdminsRoleVo;
import com.jfinal.club.vo.UserSessionVo;
import com.jfinal.kit.Ret;
import com.jfinal.plugin.activerecord.Page;
import com.sun.javafx.scene.control.skin.VirtualFlow;
import org.apache.commons.lang3.StringUtils;

import java.util.*;

/**
 * @descriptions: 后台账户admin管理
 * @author: lc
 * @date: 2020-07-15 13:37:36
 * @Version: 1.0
 **/
public class AdminAdminsController extends BaseController {


    public void index( ) {
        String text = get("searchName");
        set("searchName", text);
        if (StringUtils.isNotBlank(text)) {
            text = "%" + text + "%";
        } else {
            text = "%%";
        }
        Page< Admins > p = Admins.dao.paginate(getInt("p", 1), Cons.ADMIN_PAGESIZE, "select * ", "from admins where id != 1 and username like ?", text);
        set("page", p);
        render("index.html");
    }

    public void add( ) {
        List< Navbar > levelList = Navbar.dao.find("select * from navbar where pid = 0 order by sort desc ,create_time asc");
        List< Object > arrayList = new LinkedList<>();
        if(levelList != null && levelList.size() > 0) {
            levelList.forEach(a -> {
                AdminsRoleVo vo = new AdminsRoleVo( );
                vo.setNavbar(a);
                List< Navbar > navbars = Navbar.dao.find("select * from navbar where pid = ? order by sort desc ,create_time asc", a.getId( ));
                vo.setNavbarList(navbars);
                arrayList.add(vo);
            });
        }
        set("roleList",arrayList);
        render("add_edit.html");
    }

    public void save( ) {
        String username = get("admins.username");
        if(StringUtils.isBlank(username)){
            renderJson(Ret.fail("msg", "请填写账号信息!"));
            return;
        }

        String password = get("admins.password");
        if(StringUtils.isBlank(password)){
            renderJson(Ret.fail("msg", "密码信息不能为空!"));
            return;
        }


        String[] parameterValues = getRequest( ).getParameterValues("admins.role");
        String  roles = StringUtils.join(parameterValues,",");



        List< Admins > admins = Admins.dao.find("select * from admins where username = ? ", username.trim( ));
        if (admins != null && admins.size( ) > 0) {
            renderJson(Ret.fail("msg", "账户信息已存在!"));
            return;
        }
        getModel(Admins.class).set("create_date", new Date( )).set("lock", 0).set("role",roles == null ?0:roles).save( );
        renderJson(Ret.ok( ));
    }

    public void edit( ) {
        Integer id = getInt("id");
        Admins account = Admins.dao.findById(id);
        String[] split = account.getRole( ).split(",");
        List< String > sortList = Arrays.asList(split);
        List< Navbar > levelList = Navbar.dao.find("select * from navbar where pid = 0 order by sort desc ,create_time asc");
        List< AdminsRoleVo > arrayList = new LinkedList<>();
        if(levelList != null && levelList.size() > 0) {
            levelList.forEach(a -> {
                AdminsRoleVo vo = new AdminsRoleVo( );
                vo.setNavbar(a);
                List< Navbar > navbars = Navbar.dao.find("select * from navbar where pid = ? order by sort desc ,create_time asc ", a.getId( ));
                vo.setNavbarList(navbars);
                arrayList.add(vo);
            });
        }

        arrayList.forEach(a->{
            List< Navbar > navbarList = a.getNavbarList( );
            Navbar navbar = a.getNavbar( );
            navbarList.forEach(b->{
                if(sortList.contains(b.getId()+"")){
                    b.put("active",1);
                    navbar.put("active",1);
                }else{
                    b.put("active",0);
                }
            });
        });

        set("roleList",arrayList);


        set("admins", Admins.dao.findById(id));
        render("add_edit.html");
    }

    public void update( ) {
        String username = get("admins.username");
        if(StringUtils.isBlank(username)){
            renderJson(Ret.fail("msg", "请填写账号信息!"));
            return;
        }

        String password = get("admins.password");
        if(StringUtils.isBlank(password)){
            renderJson(Ret.fail("msg", "密码信息不能为空!"));
            return;
        }

        String[] parameterValues = getRequest( ).getParameterValues("admins.role");
        String  roles = StringUtils.join(parameterValues,",");

        Integer id = getInt("admins.id");
        List< Admins > admins = Admins.dao.find("select * from admins where id != ? and username = ? ", id, username.trim( ));
        if (admins != null && admins.size( ) > 0) {
            renderJson(Ret.fail("msg", "账户信息已存在!"));
            return;
        }
        getModel(Admins.class).set("role",roles == null ?0:roles).update( );
        renderJson(Ret.ok( ));
    }

    public void delete( ) {
        Admins.dao.deleteById(getInt("id"));
        renderJson(Ret.ok( ));
    }

    public void lock_t( ) {
        Admins.dao.findById(getInt("id")).set("lock", 1).removeNullValueAttrs( ).update( );
        index( );
    }

    public void lock_f( ) {
        Admins.dao.findById(getInt("id")).set("lock", 0).removeNullValueAttrs( ).update( );
        index( );
    }
}
