package com.jfinal.club._admin.login;

import com.jfinal.aop.Before;
import com.jfinal.aop.Clear;
import com.jfinal.club._admin.admin_interface.AdminSessionInterface;
import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.Admins;
import com.jfinal.club.common.model.Navbar;
import com.jfinal.club.util.CacheSessionUtil;
import com.jfinal.club.util.Cons;
import com.jfinal.club.util.SM4;
import com.jfinal.club.vo.AccountRole;
import com.jfinal.club.vo.UserSessionVo;
import com.jfinal.core.ActionKey;
import com.jfinal.kit.PropKit;
import com.jfinal.kit.Ret;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.mail.*;

import java.io.IOException;
import java.util.*;


/**
 * @descriptions: 登录控制
 * @author: lc
 * @date: 2020-05-09 20:02:53
 * @Version: 1.0
 **/
public class LoginAdminController extends BaseController {

    private CacheSessionUtil sessionUtil = CacheSessionUtil.getInstance( );

    /**
     * 登录界面
     */
    @Clear(AdminSessionInterface.class)
    public void index( ) {
        render("login.html");
    }

    /**
     * 后台登录 界面
     */
    @Clear(AdminSessionInterface.class)
    @Before(LoginValidator.class)
    public void login( ) {
        String username = get("username").toLowerCase( ).trim( );
        String password = get("password").trim( );

        Admins admins = Admins.dao.findFirst("select * from admins where username = ? and password = ?", username, password);

        if (admins != null) {
            if(admins.getLock() !=null && admins.getLock() == 1){
                renderJson("msg","该用户已被冻结,请联系管理员解锁!");
                return;
            }
            saveSession(admins);
            renderJson(Ret.ok("msg", "登录成功!"));
        } else {
            renderJson(Ret.fail("msg", "用户名或密码输入有误!"));
        }
    }

    /**
     * 保存session
     * @param admins
     */
    private void saveSession(Admins admins) {
        String sessionId = Cons.JSESSIONID_ADMIN + admins.getId( );
        setCookie(Cons.JSESSIONID_ADMIN, sessionId, PropKit.getInt("cookie"), Cons.ContextPath + "/admin", null, true);
        UserSessionVo sessionVo = new UserSessionVo( );
        sessionVo.setAdmins(admins);

        //id 为超级用户  默认拥有所有权限信息
        if (admins.getId( ) == 1) {
            List< Navbar > navbars = Navbar.dao.find("select * from navbar where pid > 0");
            if (navbars != null && navbars.size( ) > 0) {
                String tempRole = "";
                for (int i = 0; i < navbars.size( ); i++) {
                    tempRole += navbars.get(i).getId( ) + ",";
                }
                admins.setRole(tempRole);
            }
        }

        Map< Object, List< Navbar > > map = null;
        if (StringUtils.isNotBlank(admins.getRole( ))) {
            map = new HashMap<>( );
            String[] split = admins.getRole( ).split(",");
            for (int i = 0; i < split.length; i++) {
                Navbar navbar = Navbar.dao.findById(split[i]);

                if (navbar != null) {
                    Navbar pNavbar = Navbar.dao.findById(navbar.getPid( ));
                    if (map.containsKey(pNavbar.getName( ))) {
                        List< Navbar > navbars = map.get(pNavbar.getName( ));
                        navbars.add(navbar);
                        continue;
                    } else {
                        List< Navbar > arrList = new ArrayList<>( );
                        arrList.add(navbar);
                        map.put(pNavbar.getName( ), arrList);
                        continue;
                    }
                }
            }
        }

        List< Navbar > navbars = Navbar.dao.find("select * from navbar where pid = 0 order by sort desc,create_time asc");
        ArrayList< AccountRole > arr = new ArrayList<>( );
        for (Navbar navbar : navbars) {
            for (Map.Entry< Object, List< Navbar > > m : map.entrySet( )) {
                if (navbar.getName( ).equals(m.getKey( ).toString( ))) {
                    AccountRole accountRole = new AccountRole( );
                    accountRole.setTitle(m.getKey( ).toString( ));
                    Navbar first = Navbar.dao.findFirst("select * from navbar where pid = 0 and name = ? ", m.getKey( ).toString( ));
                    if(first != null){
                        if(StringUtils.isNotBlank(first.getIcon())){
                            accountRole.setIcon(first.getIcon());
                        }
                    }
                    accountRole.setList(m.getValue( ));
                    arr.add(accountRole);
                    continue;
                }
            }
        }
        sessionVo.setRoleList(arr);
        sessionUtil.setSession(sessionId, sessionVo);
    }

    /**
     * 退出登录
     */
    @Clear(AdminSessionInterface.class)
    public void exit( ) {
        String sessionId = getCookie(Cons.JSESSIONID_ADMIN);
        //如果有session信息就清空
        if (StringUtils.isNotBlank(sessionId)) {
            sessionUtil.delSession(sessionId);
        }
        index( );
    }

    @Clear(AdminSessionInterface.class)
    public void email( ) throws EmailException {

        MultiPartEmail multiPartEmail = new MultiPartEmail();
        //字符集
        multiPartEmail.setCharset("utf-8");
        //qq端口
        multiPartEmail.setSmtpPort(587);
        //服务器
        multiPartEmail.setHostName("smtp.qq.com");
        multiPartEmail.setAuthentication("895296059@qq.com", "mjcszpqwqkuybcbb");
        //发件人邮箱账号与上一致
        multiPartEmail.setFrom("895296059@qq.com","账号别名显示");
        //收件人邮箱
        multiPartEmail.addTo("lc895296059@163.com");
        //标题
        multiPartEmail.setSubject("邮件标题");
        //正文
        multiPartEmail.setMsg("邮件内容!");
        //设置添加附件
        EmailAttachment emailAttachment = new EmailAttachment();
        //设置文件地址
        emailAttachment.setPath("C:\\Users\\Jzdsh\\Pictures\\图\\hhh.jpg");
        //邮箱显示文件名
        emailAttachment.setName("tsy");
        //加载到邮件中
        multiPartEmail.attach(emailAttachment);
        //发送时间
        multiPartEmail.setSentDate(new Date());
        //发送
        multiPartEmail.send( );
        System.out.println("发送邮件成功！");


    }

    public static void main(String[] args) throws IOException {
        SM4 sm4 = new SM4( );
        String decode = sm4.decode("xYnWFdVOHyVGhliDIIo0fQ==", "W5#");
        System.out.println(decode);

    }

}
