package com.jfinal.club._app.appcss;

import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.*;
import com.jfinal.club.util.Cons;
import com.jfinal.kit.PathKit;
import com.jfinal.kit.Ret;
import com.jfinal.plugin.activerecord.Db;
import com.jfinal.plugin.activerecord.Page;
import com.jfinal.plugin.activerecord.Record;
import net.coobird.thumbnailator.Thumbnails;
import net.coobird.thumbnailator.geometry.Coordinate;
import org.apache.commons.lang3.StringUtils;

import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;

/**
 * @descriptions: 应用体验 index
 * @author: lc
 * @date: 2020-07-22 17:33:50
 * @Version: 1.0
 **/
public class AppCssController extends BaseController {

    /**
     * 产品查询-只查门把手的产品信息
     * <p>
     * type  产品类型
     * materialType  品质类型
     * colorType 颜色类型saveImage
     * patentType 专利技术
     * p 页码
     */
    public void index( ) {

        Integer type = getInt("type");
        Integer materialType = getInt("materialType");
        Integer colorType = getInt("colorType");
        Integer patentType = getInt("patentType");

        // 1 类型   室内门把手,门拉手......
        List< PType > typeList = PType.dao.find("select * from p_type where knob = 1 order by sort desc ,create_time desc");
        if (type == null) {
            if (typeList.size( ) > 0) {
                type = typeList.get(0).getId( );
            }
        }
        // 2 材质信息  铝合金,不锈钢 ......
        List< PMaterial > materialList = PMaterial.dao.find("select * from p_material where is_app = 1  order by sort desc,create_time desc");
        if (materialType == null) {
            if (materialList.size( ) > 0) {
                materialType = materialList.get(0).getId( );
            }
        }
        // 3 产品信息  具体产品
        //SELECT * FROM product WHERE p_type = 1 AND p_material = 1 AND FIND_IN_SET(1,p_color) AND FIND_IN_SET(1,p_patent)
        ArrayList< Object > param = new ArrayList<>( );
        String sql = " from product where is_app = 1 ";
        if (type != null) {
            sql += " and p_type = ? ";
            param.add(type);
        }
        if (materialType != null) {
            sql += " and p_material = ? ";
            param.add(materialType);
        }
        if (colorType != null) {
            sql += " and FIND_IN_SET(?,p_color) ";
            param.add(colorType);
        }
        if (patentType != null) {
            sql += "  and FIND_IN_SET(?,p_patent) ";
            param.add(patentType);
        }
        sql += " order by sort desc,create_time desc ";

        Page< Product > page = Product.dao.paginate(getInt("p", 1), getInt("s", Cons.FRONT_PAGESIZE), "select * ", sql, param.toArray( ));

        HashMap< Object, Object > map = new HashMap<>(12);
        //当前选择的类型id
        map.put("type", type);
        map.put("materialType", materialType);
        map.put("colorType", colorType);
        map.put("patentType", patentType);
        //数据类表
        map.put("typeList", typeList);
        map.put("materialList", materialList);
        map.put("page", page);
        // 默认图片以及产品id
        if (page.getList( ) != null && page.getList( ).size( ) > 0) {
            map.put("defaultId", page.getList( ).get(0).getId( ));
            map.put("defaultImg0", page.getList( ).get(0).getImgKnob( ));
        } else {
            //没有产品
            map.put("defaultId", 0);
            map.put("defaultImg0", "");
        }
        //o1 应用场景 o2门窗材质
        Record o1 = Db.findFirst("select id,img from photos where type = ? order by sort desc,create_time desc", 1);
        Record o2 = Db.findFirst("select id,img from photos where type = ? order by sort desc,create_time desc", 2);

        map.put("defaultImg1", o1.get("img"));
        map.put("defaultImg2", o2.get("img"));
        map.put("o1Id", o1.getInt("id"));
        map.put("o2Id", o2.getInt("id"));
        renderJson(Ret.ok("data", map));
    }


    /**
     * id:产品id
     * o1:场景图id ,o2:材质图id
     */
    public void saveImage( ) {
        String imgUrl = "";
        Integer o1 = getInt("o1");
        Integer o2 = getInt("o2");
        Integer id = getInt("id");
        long imgName = System.currentTimeMillis( );
        String path = PathKit.getWebRootPath( ) + "/upload" + Cons.TEMP_FILE;
        String imgPath = path + imgName + ".jpg";
        if(!new File(path).exists()){
            new File(path).mkdirs();
        }

        try {
            int width = 750;
            int height = 1100;
            Photos p1 = Photos.dao.findById(o1);
            Photos p2 = Photos.dao.findById(o2);
            Product product = Product.dao.findById(id);

            BufferedImage backgroundImage = Thumbnails.of(new File(PathKit.getWebRootPath()+p1.getImg())).size(375, 800).keepAspectRatio(false).asBufferedImage( );
            BufferedImage materialImage = Thumbnails.of(new File(PathKit.getWebRootPath()+p2.getImg())).size(300, 800).keepAspectRatio(false).asBufferedImage( );
            BufferedImage doorImage = Thumbnails.of(new File(PathKit.getWebRootPath()+product.getImgKnob())).size(320, 320).keepAspectRatio(false).asBufferedImage( );
            BufferedImage qrImage = Thumbnails.of(new File(PathKit.getWebRootPath()+"/assets/img/qr.jpg")).size(200, 247).keepAspectRatio(false).asBufferedImage( );

            //文本水印图
            BufferedImage textImage = Thumbnails.of(handleTextWaterMark(product)).size(350, 280).asBufferedImage( );

            Thumbnails.of(new File(PathKit.getWebRootPath()+"/assets/img/blank_file.jpg")).size(width, height)
                    .watermark(new Coordinate(0, 0), backgroundImage, 1f)
                    .watermark(new Coordinate((int) (width * 0.5), 0), materialImage, 1f)
                    .watermark(new Coordinate(240, 250), doorImage, 1f)
                    .watermark(new Coordinate((int) (width * 0.04), 840), textImage, 1f)
                    .watermark(new Coordinate((int) (width * 0.5), 830), qrImage, 1f)
                    .toFile(imgPath);

            imgUrl = "/upload" + Cons.TEMP_FILE + imgName + ".jpg";
        } catch (IOException e) {
            System.err.println("图片合成 io异常!");
            e.printStackTrace( );
        }
        renderJson(Ret.ok("data", imgUrl));
    }




    /**
     * @throws
     * @description 操纵文字型水印
     */
    private static BufferedImage handleTextWaterMark(Product product) {
        // 查询
        //1 产品款式
        PTitle pTitle = PTitle.dao.findById(product.getPTitle( ));
        //2 产品材质
        PMaterial pMaterial = PMaterial.dao.findById(product.getPMaterial( ));
        //3 产品颜色
        String colorStr = "";
        if(product.getPColor() != null){
            PColor pColor = PColor.dao.findById(product.getPColor());
            colorStr += pColor.getColorCn();
        }

        // 产品专利
        String patentStr = "";
        if(StringUtils.isNotBlank(product.getPPatent())){
            String[] split = product.getPPatent( ).split(",");
            for (int i = 0; i < split.length; i++) {
                String id = split[i];
                PPatent pPatent = PPatent.dao.findById(id);
                patentStr += pPatent.getName() + ",";
            }
            patentStr = patentStr.substring(0,patentStr.lastIndexOf(","));
        }

        // 设置文字样式
        Font font = new Font("微软雅黑", Font.BOLD, 30);
        //创建缓存图
        BufferedImage image = new BufferedImage(400, 400, BufferedImage.TYPE_INT_RGB);
        //生成图片
        Graphics2D g = image.createGraphics( );
        //设置图片透明度为透明
        image = g.getDeviceConfiguration( ).createCompatibleImage(400, 400, Transparency.TRANSLUCENT);

        //设置文本 距离
        int y = 0;
        int distTop = 45;

        g = image.createGraphics( );
        g.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        g.setColor(Color.black);
        g.setFont(font);


        g.drawString(pTitle.getName(), 5, y += distTop);
        g.setColor(new Color(102, 102, 102));
        g.setFont(new Font("微软雅黑", Font.CENTER_BASELINE, 24));
        g.drawString(product.getModel(), 5, y += distTop);
        g.drawString("材质："+pMaterial.getName(), 5, y += distTop);
        g.drawString("颜色："+colorStr, 5, y += distTop);
        g.drawString("专利："+patentStr, 5, y += distTop);
        g.dispose( );
        return image;
    }


}
