package com.jfinal.club._app.home;

import com.alibaba.fastjson.JSONObject;
import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.*;
import com.jfinal.club.common.model.Collection;
import com.jfinal.club.util.Cons;
import com.jfinal.json.Json;
import com.jfinal.kit.Ret;
import com.jfinal.plugin.activerecord.Db;
import com.jfinal.plugin.activerecord.IAtom;
import com.jfinal.plugin.activerecord.Page;
import com.jfinal.plugin.activerecord.Record;
import com.jfinal.upload.UploadFile;
import org.apache.commons.lang.time.DateFormatUtils;
import org.apache.commons.lang3.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.sql.SQLException;
import java.util.*;

/**
 * @descriptions: 首页
 * @author: lc
 * @date: 2020-07-16 18:32:27
 * @Version: 1.0
 **/
public class IndexController extends BaseController {

    public void index() {

        //如果是浏览器就进入到 后台登录页面  如果是小程序就返回数据
        HttpServletRequest request = getRequest();
        if (request.getHeader("content-type") == null && request.getHeader("accept") != null) {
            redirect("/admin");
        } else {
            List<Banner> bannerList = Banner.dao.find("select * from banner order by sort desc,create_time desc");
            List<News> newsList = News.dao.find(" select id,title,img,pubdate from news where recommend = 1 order by sort desc,pubdate desc ");
            if (newsList != null && newsList.size() > 0) {
                newsList.forEach(a -> a.put("formatDate", DateFormatUtils.format(a.getPubdate(), "yyyy-MM-dd")));
            }
            List<Product> productList = Product.dao.find("SELECT b.name title,a.id,a.cover_img,a.model,p_style,p_patent FROM product a left join p_title b ON a.p_title=b.id  WHERE a.is_recommend = 1 ");
            if (productList != null && productList.size() > 0) {
                productList.forEach(a -> {
                    //产品专利
                    List<PPatent> pPatents = new ArrayList<>();
                    if (StringUtils.isNotBlank(a.getPPatent())) {
                        String[] strings = StringUtils.splitPreserveAllTokens(a.getPPatent(), ",");
                        ArrayList<Object> param = new ArrayList<>();
                        String sql = "(";
                        for (int i = 0; i < strings.length; i++) {
                            if (i == strings.length - 1) {
                                sql += " ? ";
                            } else {
                                sql += " ?, ";
                            }
                            param.add(strings[i]);
                        }
                        sql += ")";
                        pPatents = PPatent.dao.find("select id,name,logo from p_patent where id in " + sql + "", param.toArray());
                    }
                    a.put("patentList", pPatents);

                    // List< AttrP > attrPS = AttrP.dao.find("select * from attr_p where pid = ? ", a.getId( ));
                    List<PAttr> attrPS = new ArrayList<>();
                    if (StringUtils.isNotBlank(a.getPAttr())) {
                        attrPS = PAttr.dao.find("SELECT name title,img FROM p_attr WHERE id IN (?)", a.getPAttr());
                    }
                    a.put("attrList", attrPS);
                });
            }

            HashMap<Object, Object> map = new HashMap<>(3);
            map.put("bannerList", bannerList);
            map.put("newsList", newsList);
            map.put("productList", productList);
            renderJson(Ret.ok("data", map));
        }
    }

    /**
     * 点击搜索触发  热门搜索
     */
    public void hotSearch() {
        List<HotSearch> hotSearches = HotSearch.dao.find("select title from hot_search where type = 2");
        HashMap<Object, Object> map = new HashMap<>(1);
        map.put("hotList", hotSearches);
        renderJson(Ret.ok("data", map));
    }

    /**
     * searchName : 搜索参数
     * 搜索 内容可以是
     * 款式 ， 型号， 产品类型  ，材质 ，  4 个方面都可以搜索到
     * openid: 微信用户唯一标识
     */
    public void search() {
        String openid = get("openid");
        HashMap<Object, Object> map = new HashMap<>(2);
        ArrayList<Object> param = new ArrayList<>();
        String searchName = get("searchName");
        Integer materialId = getInt("materialId", 0);
        Integer colorId = getInt("colorId", 0);
        map.put("currentSearchName", searchName);

        String sql = " from (";
        sql += "SELECT a.id,b.name titleName, c.name typeName,d.name mateName, a.model,a.cover_img,a.sort,a.p_material,a.p_color FROM ( ";
        sql += " SELECT * FROM (SELECT id,MAX(subsort) subsort,model,sort,cover_img,p_title,p_type,p_material,p_color,p_patent FROM product  GROUP BY model,id ORDER BY sort desc,subsort DESC ) a where 1=1 ";

        if (materialId > 0) {
            sql += " and p_material = ? ";
            param.add(materialId);
        }
        if (colorId > 0) {
            sql += " and p_color = ? ";
            param.add(colorId);
        }

        sql += " GROUP BY model order by sort desc ";
        sql += " ) ";
        sql += " a LEFT JOIN p_title b ON a.p_title = b.id LEFT JOIN p_type c ON a.p_type = c.id LEFT JOIN p_material d ON a.p_material = d.id ";
        sql += " ) temp where 1 = 1 ";

        if (StringUtils.isNotBlank(searchName)) {
            searchName = "%" + searchName.trim() + "%";
            sql += "  AND (titleName LIKE ? OR typeName LIKE ? OR mateName LIKE ? OR model LIKE ? ) ";
            param.add(searchName);
            param.add(searchName);
            param.add(searchName);
            param.add(searchName);
        }

        sql += " GROUP BY model ORDER BY sort DESC ";

        Page<Record> page = Db.paginate(getInt("p", 1), 100, "select * ", sql, param.toArray());
        map.put("page", page);
        //记录搜索日志
        searchResult(openid, get("searchName"), page.getTotalRow());
        renderJson(Ret.ok("data", map));
    }

    /**
     * 产品搜索日志记录
     *
     * @param openid       微信
     * @param searchName   搜索关键字
     * @param resultNumber 结果数量
     */
    private void searchResult(String openid, String searchName, Integer resultNumber) {
        if (StringUtils.isNotBlank(searchName) && StringUtils.isNotBlank(openid)) {
            WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);
            SearchProductLog productLog = new SearchProductLog();
            productLog.setUid(wxUser.getId());
            productLog.setKeyword(searchName.trim());
            productLog.setResult(resultNumber);
            productLog.setCreateTime(new Date());
            productLog.save();
        }
    }

    /**
     * 获取openid
     */
    public void getOpenid() {
        String jscode = get("jscode");
        String p = "https://api.weixin.qq.com/sns/jscode2session?appid=wx5f82870d07d8d011&secret=c1a8aed85d41018dd9b211541c77b3aa&js_code=" + jscode + "&grant_type=authorization_code";
        //String p = "http://127.0.0.1:81/search";
        String result = "";
        BufferedReader in = null;
        try {
            URL realUrl = new URL(p);
            // 打开和URL之间的连接
            URLConnection connection = realUrl.openConnection();
            // 设置通用的请求属性
            connection.setRequestProperty("accept", "*/*");
            connection.setRequestProperty("connection", "Keep-Alive");
            connection.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
            // 建立实际的连接
            connection.connect();
            // 定义 BufferedReader输入流来读取URL的响应
            in = new BufferedReader(new InputStreamReader(connection.getInputStream(), "utf-8"));
            String line;
            while ((line = in.readLine()) != null) {
                result += line;
            }
        } catch (Exception e) {
            e.printStackTrace();
            renderJson(Ret.fail("msg", "接口异常"));
        }
        // 使用finally块来关闭输入流
        finally {
            try {
                if (in != null) {
                    in.close();
                }
            } catch (Exception e2) {
                e2.printStackTrace();
                renderJson(Ret.fail("msg", "接口异常"));
            }
        }
        //System.err.println("总结果" + result);
        JSONObject json = JSONObject.parseObject(result);
        String openid = json.getString("openid");
        // String session_key = json.getString("session_key");
        // String unionid = json.getString("unionid");
        String errcode = json.getString("errcode");
        // String errmsg = json.getString("errmsg");
        renderJson(Ret.ok("msg", "请求成功").set("openid", openid));
        /*System.err.println("openid" + openid);*/
        //System.err.println("errcode"+errcode );
        if (StringUtils.isNotBlank(openid)) {
            renderJson(Ret.ok("msg", "请求成功").set("openid", openid));
            return;
        }
/*        if(errcode.equals("0")){
            renderJson(Ret.ok("msg","请求成功").set("openid",openid));
            return;
        }
        if(errcode == -1){
            renderJson(Ret.fail("msg","系统繁忙，此时请开发者稍候再试"));
            return;
        }

        if(errcode == 40029){
            renderJson(Ret.fail("msg","code 无效"));
            return;
        }
        if(errcode == 45011){
            renderJson(Ret.fail("msg","频率限制，每个用户每分钟100次"));
            return;
        }*/

    }

    /**
     * 用户进入小程序，需要保存用户openid信息
     * openid : 用户在该小程序的唯一标识
     */
    public void wxLogin() {
        String openid = get("openid");
        if (StringUtils.isBlank(openid)) {
            renderJson(Ret.fail("msg", "openid不能为空"));
            return;
        }
        WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);
        //新用户
        if (wxUser == null) {
            WxUser user = new WxUser();
            user.setOpenid(openid);
            user.setLogins(0);
            user.setCreateTime(new Date());
            user.setLoginTime(new Date());
            user.save();
        } else {
            //老用户 登录次数加1
            wxUser.setLoginTime(new Date());
            Integer times = wxUser.getLogins();
            wxUser.setLogins(times + 1);
            wxUser.update();
        }
        renderJson(Ret.ok());
    }

    /**
     * 查询所有省份
     */
    public void listProvince() {
        try {
            List<Area> areas = Area.dao.find("SELECT * FROM area WHERE TYPE = 01");
            renderJson(Ret.ok().set("msg", "查询成功~").set("data", areas));
        } catch (Exception e) {
            e.printStackTrace();
            renderJson(Ret.fail("msg", "程序异常~"));
        }
    }

    /**
     * 查询省份下的城市
     * code  省份code
     */
    public void listCity() {
        try {
            String code = get("code");
            if (StringUtils.isBlank(code)) {
                renderJson(Ret.fail("msg", "省份code不等于空~"));
                return;
            }
            List<Area> areas = Area.dao.find("SELECT * FROM area WHERE TYPE = 02 AND father_code = ? ", code);
            renderJson(Ret.ok().set("msg", "查询成功~").set("data", areas));
        } catch (Exception e) {
            e.printStackTrace();
            renderJson(Ret.fail("msg", "程序异常~"));
        }
    }

    /**
     * 查询城市下的区县
     * code  城市code
     */
    public void listDistrict() {
        try {
            String code = get("code");
            if (StringUtils.isBlank(code)) {
                renderJson(Ret.fail("msg", "城市code不等于空~"));
                return;
            }
            List<Area> areas = Area.dao.find("SELECT * FROM area WHERE TYPE = 03 AND father_code = ? ", code);
            renderJson(Ret.ok().set("msg", "查询成功~").set("data", areas));
        } catch (Exception e) {
            e.printStackTrace();
            renderJson(Ret.fail("msg", "程序异常~"));
        }
    }

    /**
     * 展会登记表  登录   post提交
     */
    public void registrationForm() {
        try {
            //getFile( );
            String openid = get("openid");
            Integer language = getInt("language");
            String company = get("company");
            String name = get("name");
            String address = get("address");
            String country = get("country");
            String staff_size = get("staff_size");
            String phone = get("phone");
            String email = get("email");
            String industry = get("industry");
            String industry_other = get("industry_other");
            String interest = get("interest");
            String interest_other = get("interest_other");
            String know_product = get("know_product");

            if (StringUtils.isBlank(openid)) {
                renderJson(Ret.fail("msg", "openid不等于空~"));
                return;
            }
            RegistrationForm first = RegistrationForm.dao.findFirst("select * from registration_form where openid = ? ", openid);
            if (first != null) {
                RegistrationForm.dao.deleteById(first.getId());
            }
            RegistrationForm r = new RegistrationForm();
            r.setOpenid(openid);
            r.setLanguage(language);
            r.setCompany(company);
            r.setName(name);
            r.setAddress(address);
            r.setCountry(country);
            r.setStaffSize(staff_size);
            r.setPhone(phone);
            r.setEmail(email);
            r.setIndustry(industry);
            r.setIndustryOther(industry_other);
            r.setInterest(interest);
            r.setIndustryOther(interest_other);
            r.setKnowProduct(know_product);
            r.setCreateTime(new Date());
            r.save();
            renderJson(Ret.ok("msg", "保存成功~"));
        } catch (Exception e) {
            e.printStackTrace();
            renderJson(Ret.fail("msg", "程序异常~"));
        }
    }

    /**
     * 微信授权 获取用户头像 昵称 手机号
     */
    public void wxAuth() {
        String openid = get("openid");

        String avatar = get("avatar", "");
        String nickname = get("nickname", "");
        String mobile = get("mobile", "");

        WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);

        if (wxUser == null) {
            renderJson(Ret.fail().set("msg", "未找到该用户信息,用户openid异常!"));
            return;
        }

        if (StringUtils.isNotBlank(avatar)) {
            wxUser.setAvatar(avatar);
        }
        if (StringUtils.isNotBlank(nickname)) {
            wxUser.setNickname(nickname);
        }
        if (StringUtils.isNotBlank(mobile)) {
            wxUser.setMobile(mobile);
        }
        wxUser.update();

        renderJson(Ret.ok());
    }

    /**
     * 是否已授权
     */
    public void isAuth() {
        String openid = get("openid");
        WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);
        if (wxUser == null) {
            renderJson(Ret.fail("msg", "未找到该用户信息,用户openid异常!"));
            return;
        }

        if (StringUtils.isBlank(wxUser.getNickname())) {
            renderJson(Ret.fail("msg", "该用户未授权"));
            return;
        }

        renderJson(Ret.ok().set("msg", "已授权"));
    }

    /**
     * 添加收藏 取消收藏
     */
    public void addCollection() {
        String openid = get("openid");
        Integer pid = getInt("pid");
        WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);

        if (wxUser == null) {
            renderJson(Ret.fail("msg", "未找到该用户信息,用户openid异常!"));
            return;
        }

        if (wxUser.getLock().intValue() == 1) {
            renderJson(Ret.fail("msg", "该用户已被冻结,请联系管理员解封!"));
            return;
        }

        if (StringUtils.isBlank(wxUser.getNickname())) {
            renderJson(Ret.fail("msg", "该用户微信未授权"));
            return;
        }

        Collection coll = Collection.dao.findFirst("select * from collection where openid = ? and pid = ? ", openid, pid);
        if(coll == null){
            //收藏成功
            Collection c = new Collection();
            c.setOpenid(openid);
            c.setPid(pid);
            c.setCreateTime(new Date());
            c.save();
            renderJson(Ret.ok().set("isColl",1).set("msg","收藏成功！"));
        }else{
            Collection.dao.deleteById(coll.getId());
            renderJson(Ret.ok().set("isColl",0).set("msg","取消收藏!"));
        }


    }

    /**
     * 个人中心收藏列表
     */
    public void collectionList() {
        String openid = get("openid");
        List<Collection> collectionList = Collection.dao.find("SELECT a.id,b.id pid,b.cover_img,c.name,b.model FROM collection a INNER JOIN product b ON a.pid= b.id  INNER JOIN p_title c ON b.p_title = c.id  WHERE a.openid= ? ORDER BY a.create_time desc", openid);

        renderJson(Ret.ok().set("data", collectionList));
    }

    /**
     * 收藏列表 删除
     */
    public void collectionDelete() {
        Integer id = getInt("id");
        if (id == null) {
            renderJson(Ret.fail().set("msg", "id为空"));
            return;
        }
        Collection.dao.deleteById(id);
        renderJson(Ret.ok());
    }

    /**
     * 个人信息
     */
    public void profile() {
        String openid = get("openid", "");
        WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);
        if (wxUser == null) {
            renderJson(Ret.fail().set("msg", "未找到该用户信息,用户openid异常!"));
            return;
        }
        renderJson(Ret.ok().set("data", wxUser));
    }

    /**
     * 更新用户信息
     */
    public void updateProfile() {
        String openid = get("openid", "");
        String mobile = get("mobile", "");
        String email = get("email", "");
        String company = get("company", "");
        String job = get("job", "");
        WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);

        if (wxUser == null) {
            renderJson(Ret.fail().set("msg", "未找到该用户信息,用户openid异常!"));
            return;
        }


        if (wxUser.getLock().intValue() == 1) {
            renderJson(Ret.fail("msg", "该用户已被冻结,请联系管理员解封!"));
            return;
        }

        if (StringUtils.isBlank(wxUser.getNickname())) {
            renderJson(Ret.fail("msg", "该用户微信未授权"));
            return;
        }

        wxUser.setMobile(mobile);
        wxUser.setEmail(email);
        wxUser.setCompany(company);
        wxUser.setJob(job);
        wxUser.update();

        renderJson(Ret.ok());
    }

}
