package com.jfinal.club._app.home;

import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.*;
import com.jfinal.club.util.Cons;
import com.jfinal.club.util.MapUtils;
import com.jfinal.club.vo.CityVo;
import com.jfinal.kit.Ret;
import com.jfinal.plugin.activerecord.Db;
import com.jfinal.plugin.activerecord.Page;
import com.jfinal.plugin.activerecord.Record;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * @descriptions: 附近门店
 * @author: lc
 * @date: 2020-07-22 10:53:10
 * @Version: 1.0
 **/
public class NearStoreController extends BaseController {

    /**
     * longitude : 经度
     * latitude ：纬度
     * city : 城市 默认根据经纬度查出来的城市
     * searchName ： 搜索名 别名 、点名 、地址 三个条件查
     * p： 页码
     * openid : openid
     */
    public void index( ) {

        String openid = get("openid");

        String cityS = get("city");
        String cityCode;
        String searchName = get("searchName");
        String longitude = get("longitude", "113.622178");
        String latitude = get("latitude", "34.764247");

        String regeoUrl = MapUtils.getRegeoUrl(longitude + "," + latitude);
        String jsonStr = MapUtils.sendGet(regeoUrl);
        String city = MapUtils.getCity(jsonStr);
        if (StringUtils.isBlank(cityS)) {
            Area area = Area.dao.findFirst(" SELECT * FROM area WHERE TYPE = 02 AND addr_name = ? ", city);
            cityS = area.getCity( );
            cityCode = area.getAddrCode( );
        } else {
            Area area = Area.dao.findFirst(" SELECT * FROM area WHERE TYPE = 02 AND (city like ? or addr_name like ? ) ", "%" + cityS + "%", "%" + cityS + "%");
            cityS = area.getCity( );
            cityCode = area.getAddrCode( );
        }

        ArrayList< Object > param = new ArrayList<>( );
        String sql = " from (" +
                "  SELECT  id,a.name,a.img,a.font_address,a.last_address,tel,round(sqrt(" +
                "        (" +
                "        ((" + longitude + " -longitude)*PI()*12656*cos(((" + latitude + " +latitude)/2)*PI()/180)/180)" +
                "        *" +
                "        ((" + longitude + " -longitude)*PI()*12656* (((" + latitude + "+latitude)/2)*PI()/180)/180)" +
                "        )" +
                "        +" +
                "        (" +
                "        ((" + latitude + "-latitude)*PI()*12656/180)" +
                "        *" +
                "        ((" + latitude + "-latitude)*PI()*12656/180)" +
                "        )" +
                "        )/2,2) distance FROM store a WHERE shelf = 0 ";
        if (StringUtils.isNotBlank(searchName)) {
            searchName = "%" + searchName.trim( ) + "%";
            sql += " AND (a.name LIKE ? or a.last_address LIKE ? OR a.alias_search LIKE ?) ";
            param.add(searchName);
            param.add(searchName);
            param.add(searchName);
        }else if(StringUtils.isNotBlank(cityCode)) {
            sql += " and city = ? ";
            param.add(cityCode);
        }
        sql += "  ORDER BY sort DESC,create_time desc ";
        sql += " )  tb ORDER BY distance ASC ";
        Page< Store > page = Store.dao.paginate(getInt("p", 1), getInt("s", Cons.FRONT_PAGESIZE), "select *", sql, param.toArray( ));

        HashMap< Object, Object > map = new HashMap<>(4);
        map.put("page", page);
        map.put("currentCity", cityS);
        //搜索结果记录日志
        searchResult(openid, get("searchName"), page.getTotalRow( ));
        renderJson(Ret.ok("data", map));
    }


    /**
     * longitude : 经度
     * latitude ：纬度
     * 热门 搜索记录
     */
    public void clickSearch( ) {
        String longitude = get("longitude", "113.622178");
        String latitude = get("latitude", "34.764247");
        List< HotSearch > hotSearches = HotSearch.dao.find("select title from hot_search where type = 1");
        HashMap< Object, Object > map = new HashMap<>(3);
        map.put("longitude", longitude);
        map.put("latitude", latitude);
        map.put("hotList", hotSearches);
        renderJson(Ret.ok("data", map));
    }


    /**
     * 点击上海
     * 热门城市接口
     * 后台都可自定义-热门城市
     */
    public void hotCity( ) {
        List< Record > hotCityList = Db.find("SELECT id,city,remark,hot,sort FROM area WHERE TYPE = 02  and city != '省直辖县级行政区划' AND city != '省直辖县级行政单位' AND city != '自治区直辖县级行政区划' AND hot = 1 ORDER BY sort desc ");
        List< Area > reRemarkList = Area.dao.find("SELECT remark FROM area WHERE TYPE = 02 GROUP BY remark ");
        ArrayList< CityVo > arrayList = new ArrayList<>( );
        reRemarkList.forEach(a -> {
            CityVo vo = new CityVo( );
            vo.setLetter(a.getRemark( ));
            List< Object > cityList = Db.query(" SELECT city FROM area WHERE TYPE = 02  and city != '省直辖县级行政区划' AND city != '省直辖县级行政单位' AND city != '自治区直辖县级行政区划' and remark = ?  ORDER BY remark ASC,sort DESC ", a.getRemark( ));
            vo.setData(cityList);
            arrayList.add(vo);
        });
        HashMap< Object, Object > map = new HashMap<>(2);
        map.put("hotCityList", hotCityList);
        map.put("allList", arrayList);
        renderJson(Ret.ok("data", map));
    }


    /**
     * 附近门店搜索日志记录
     * @param openid  微信
     * @param searchName  搜索关键字
     * @param resultNumber 结果数量
     */
    private void searchResult(String openid, String searchName, Integer resultNumber) {
        if (StringUtils.isBlank(searchName) || StringUtils.isBlank(openid)) {
            return;
        }
        WxUser wxUser = WxUser.dao.findFirst("select * from wx_user where openid = ? ", openid);
        SearchStoreLog storeLog = new SearchStoreLog( );
        storeLog.setUid(wxUser.getId( ));
        storeLog.setKeyword(searchName.trim());
        storeLog.setResult(resultNumber);
        storeLog.setCreateTime(new Date( ));
        storeLog.save( );
    }

}
