package com.jfinal.club._app.productCenter;

import com.jfinal.club.common.controller.BaseController;
import com.jfinal.club.common.model.*;
import com.jfinal.club.util.CommonUtil;
import com.jfinal.club.util.Cons;
import com.jfinal.kit.PathKit;
import com.jfinal.kit.Ret;
import com.jfinal.plugin.activerecord.Page;
import net.coobird.thumbnailator.Thumbnails;
import net.coobird.thumbnailator.geometry.Positions;
import org.apache.commons.lang3.StringUtils;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * @descriptions: 产品中心
 * @author: lc
 * @date: 2020-07-17 13:51:20
 * @Version: 1.0
 **/
public class ProductController extends BaseController {

    public void index( ) {
        Integer type = getInt("type");
        Integer materialType = getInt("activeType");
        Integer colorType = getInt("colorType");
        Integer patentType = getInt("patentType");

        //1 产品类型列表
        List< PType > pTypes = PType.dao.find("select * from p_type order by sort desc,create_time desc");
        if (type == null) {
            type = pTypes.get(0).getId( );
        }

        ArrayList< Object > param = new ArrayList<>( );
        String sql = "  FROM ( SELECT b.name title,a.* FROM (  ";
        sql += " SELECT * FROM (SELECT id,MAX(subsort) subsort,model,sort,cover_img,p_title,p_type,p_material,p_color,p_patent FROM product  GROUP BY model,id ORDER BY sort desc,subsort DESC ) a  GROUP BY model order by sort desc ";
        sql += " ) a inner join p_title b ON a.p_title=b.id WHERE 1=1 " ;

        if (type != null) {
            sql += " and a.p_type = ? ";
            param.add(type);
        }
        if (materialType != null) {
            sql += " and a.p_material = ? ";
            param.add(materialType);
        }

        if (colorType != null) {
            sql += " and FIND_IN_SET(?,a.p_color) ";
            param.add(colorType);
        }
        if (patentType != null) {
            sql += "  and FIND_IN_SET(?,a.p_patent) ";
            param.add(patentType);
        }
        sql += ") temp ORDER BY sort DESC ";

        //2 产品信息, 默认第一个产品类型的产品信息
        Page< Product > page = Product.dao.paginate(getInt("p", 1), getInt("s", Cons.FRONT_PAGESIZE), "SELECT * ", sql, param.toArray());

        HashMap< Object, Object > map = new HashMap<>(3);
        map.put("page", page);
        map.put("currentType", type);
        map.put("types", pTypes);
        renderJson(Ret.ok("data", map));
    }

    public void detail( ) {
        Integer id = getInt("id");
        String openid = get("openid", "");
        Product product = Product.dao.findFirst("select b.name title,a.* from product a inner join p_title b on a.p_title = b.id where a.id = ? ",id);
        //颜色分类
        //List< ColorTypeP > colorTypePS = ColorTypeP.dao.find("select id,title,img from color_type_p where pid = ? ", id);
        List< Product > colorTypePS = Product.dao.find("  select a.id,b.id color_id,a.cover_img,b.code,b.color_cn from product a ,p_color b where a.p_color = b.id and model = ? group BY CODE order BY b.code asc ", product.getModel( ));
        //轴长
        List< AxialP > axialPS = AxialP.dao.find("select id,title,img from axial_p where pid = ? ", id);
        //产品属性
        //List< AttrP > attrPS = AttrP.dao.find("select id,title,img from attr_p where pid = ? ", id);
        List< PAttr > attrPS = new ArrayList<>();
        if(StringUtils.isNotBlank(product.getPAttr())){
            String pAttr = product.getPAttr( );
            attrPS = PAttr.dao.find("SELECT name title,img,a.show FROM p_attr a WHERE id IN ("+pAttr+") order by sort DESC,create_time desc ");
        }
        //扩展属性(已废除)
       // List< AttrExtP > attrExtPS = AttrExtP.dao.find("select id,a.key,a.value from attr_ext_p a where pid = ? ", id);
        //风格系列
        PStyle style = PStyle.dao.findFirst("select id,name,logo from p_style where id = ? order by sort DESC,create_time desc ", product.getPStyle( ));
        //产品专利
        List< PPatent > pPatents = new ArrayList<>( );
        if (StringUtils.isNotBlank(product.getPPatent( ))) {
            String[] strings = StringUtils.splitPreserveAllTokens(product.getPPatent( ), ",");
            ArrayList< Object > param = new ArrayList<>( );
            String sql = "(";
            for (int i = 0; i < strings.length; i++) {
                if (i == strings.length - 1) {
                    sql += " ? ";
                } else {
                    sql += " ?, ";
                }
                param.add(strings[i]);
            }
            sql += ")";
            pPatents = PPatent.dao.find("select id,name,logo from p_patent where id in " + sql + " order by sort desc,create_time desc ", param.toArray( ));
        }
        //产品材质  不锈钢...
        PMaterial pMaterial = PMaterial.dao.findFirst("select id,name from p_material where id = ? ", product.getPMaterial( ));
        HashMap< Object, Object > map = new HashMap<>(11);
        map.put("style", style);
        map.put("material", pMaterial);
        map.put("product", product);
        map.put("patentList", pPatents);
        map.put("colorTypeList", colorTypePS);
        map.put("axialList", axialPS);
        map.put("attrList", attrPS);
        //安装距离 , 门厚 ，锁孔，hcs位置，平移配置,轴长 ， 尺寸,面板，方向 ，list
        List< Product > fixed_distance = Product.dao.find(" SELECT id,fixed_distance FROM product WHERE model = ? AND p_color = ? AND fixed_distance IS NOT NULL AND fixed_distance != \"\" ORDER BY fixed_distance*1 asc ", product.getModel( ), product.getPColor( ));
        map.put("fixedDistanceList",fixed_distance);
        List< Product > door_thickness = Product.dao.find(" SELECT id,door_thickness FROM product WHERE model = ? AND p_color = ? AND door_thickness IS NOT NULL AND door_thickness != \"\" ORDER BY door_thickness*1 asc ", product.getModel( ), product.getPColor( ));
        map.put("doorThicknessList",door_thickness);
        List< Product > p_Keyhole = Product.dao.find(" SELECT a.id,b.img,b.size FROM product a INNER JOIN p_keyhole b ON a.p_keyhole = b.id WHERE model = ? AND p_color = ? order by b.size asc", product.getModel( ), product.getPColor( ));
        map.put("keyholeList",p_Keyhole);
        List< Product > hcs_config = Product.dao.find(" SELECT id,hcs_config FROM product WHERE model = ? AND p_color = ? AND hcs_config IS NOT NULL AND hcs_config != \"\" ORDER BY hcs_config*1 asc ", product.getModel( ), product.getPColor( ));
        map.put("hcsConfigList",hcs_config);
        List< Product > pym_config = Product.dao.find(" SELECT  id,substring(pym_config,3) pym_config FROM (SELECT id, pym_config  FROM product WHERE model = ? AND p_color = ? AND pym_config IS NOT NULL AND pym_config != \"\" ORDER BY pym_config ASC) a ", product.getModel( ), product.getPColor( ));
        map.put("pymConfigList",pym_config);
        List< Product > axial_length = Product.dao.find(" SELECT id,axial_length FROM product WHERE model = ? AND p_color = ? AND axial_length IS NOT NULL AND axial_length != \"\" ORDER BY axial_length*1 asc ", product.getModel( ), product.getPColor( ));
        map.put("axialLengthList",axial_length);
        List< Product > panel_size = Product.dao.find(" SELECT id,panel_size FROM product WHERE model = ? AND p_color = ? AND panel_size IS NOT NULL AND panel_size != \"\" ORDER BY panel_size*1 asc ", product.getModel( ), product.getPColor( ));
        map.put("panelSizeList",panel_size);
        List< Product > measure = Product.dao.find(" SELECT id,measure FROM product WHERE model = ? AND p_color = ? AND measure IS NOT NULL AND measure != \"\" ORDER BY measure*1 asc ", product.getModel( ), product.getPColor( ));
        map.put("measureList",measure);
        List< Product > direction = Product.dao.find(" SELECT id,direction FROM product WHERE model = ? AND p_color = ? AND direction IS NOT NULL AND direction != \"\" ORDER BY direction desc ", product.getModel( ), product.getPColor( ));
        map.put("directionList",direction);

        //判断是否收藏
        Integer isColl = 0;
        if(StringUtils.isNotBlank(openid)){
            Collection c = Collection.dao.findFirst("select * from collection where openid = ? and pid = ? ", openid, product.getId());
            if(c != null){
                isColl = 1;
            }
        }

        renderJson(Ret.ok("data", map).set("isColl",isColl));
    }

    /**
     * 产品中心 与应用体验 同一个接口
     * 产品 筛选器
     */
    public void productScreen( ) {
        // 1 材质信息类型
        List< PMaterial > materialList = PMaterial.dao.find("select * from p_material order by sort desc,create_time desc ");
        // 2 颜色信息类型
        List< PColor > colorList = PColor.dao.find("select id,color_cn name,color_img from p_color order by sort desc,create_time desc ");
        // 3 专利属性类型
        List< PPatent > patentList = PPatent.dao.find("select * from p_patent order by sort desc,create_time desc ");

        HashMap< Object, Object > map = new HashMap<>(3);
        map.put("materialList", materialList);
        map.put("colorList", colorList);
        map.put("patentList", patentList);
        renderJson(Ret.ok("data", map));
    }

    /**
     * 根据材质查询颜色列表
     *  id ：材质id
     */
    public void listColorByMaterial(){
        Integer id = getInt("id");
        if(id != null){
            List< PColor > colorList = PColor.dao.find("select id,color_cn name,color_img from p_color where material_id = ? order by sort desc,create_time desc ",id);
            renderJson(Ret.ok("data",colorList));
        }else{
            renderJson(Ret.fail("data","error!,您的id为:"+id));
        }
    }


    /**
     * 水印图
     * 点击图片放大图中央要加水印
     */
    public void watermark(){
        Ret ok = Ret.ok( );
        String imgPath = "";
        try {
            Integer id = getInt("id");
            Product product = Product.dao.findById(id);
            imgPath = createWatermark(product);
        } catch (Exception e) {
            e.printStackTrace( );
        }
        renderJson(ok.set("data",imgPath));
    }

    private String createWatermark(Product product){
        String folder = "/upload/product/watermark/";
        String imgPath = "";
        if(StringUtils.isBlank(product.getCoverImg())){
            return imgPath;
        }
        try {
            String sourceImgPath = PathKit.getWebRootPath( )+product.getCoverImg();
            File file = new File(PathKit.getWebRootPath( ) + folder);
            if(!file.exists()){
                file.mkdirs();
            }
            String filePath = folder+System.currentTimeMillis( ) + CommonUtil.getRandom(6) + ".jpg";
            String path = PathKit.getWebRootPath( ) + filePath;

            BufferedImage bufferedImage = Thumbnails.of(sourceImgPath).size(1224, 1200).asBufferedImage( );
            bufferedImage.getWidth();
            if(bufferedImage.getWidth() <= 285){
                Thumbnails.of(sourceImgPath).size(1224,1200).rotate(90)
                        .watermark(Positions.CENTER, ImageIO.read(new File(PathKit.getWebRootPath()+"/assets/img/logo.png")), 0.4f).rotate(-90)
                        .outputQuality(1f).toFile(path);
            }else{
                Thumbnails.of(sourceImgPath).size(1224,1200)
                        .watermark(Positions.CENTER, ImageIO.read(new File(PathKit.getWebRootPath()+"/assets/img/logo.png")), 0.4f)
                        .outputQuality(1f).toFile(path);
            }
            product.setWatermarkImg(filePath);
            product.update();
            imgPath = filePath;
        } catch (IOException e) {
            e.printStackTrace( );
        }
        return imgPath;
    }


}
